@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.3
-id: yesod-1.4.3-ed4e601738bb2031a01cdc5cb6b4de1d
-key: yesod_IvNIyO7ANUE9TjbCAleZ6n
+id: yesod-1.4.3-8c82bb836d4a356b4f8138aedc5d1e45
+key: yesod_CKNJftxttR03Ah7ZXh3RO2
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.3
-hs-libraries: HSyesod-1.4.3-IvNIyO7ANUE9TjbCAleZ6n
+hs-libraries: HSyesod-1.4.3-CKNJftxttR03Ah7ZXh3RO2
 depends:
     aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -46,12 +46,12 @@ depends:
     wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
     wai-extra-3.0.15.1-954bd1f4cbd0dadcc30817e6afe9d17a
     wai-logger-2.2.7-be4dfe43e81d159502c14b31210da2fe
-    warp-3.2.6-747ccbb2aaea6b63942f452bd0d269ae
+    warp-3.2.6-0273436dc44d76eb20f09024e8daa00c
     yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
-    yesod-auth-1.4.13.2-ee0da37f7df57ee3b9394d8946c3e74c
-    yesod-core-1.4.20.2-014d072d2152bbd04ae4cfe76f84438d
-    yesod-form-1.4.7.1-ba5ac4a6723307832a83abce64a93dfc
-    yesod-persistent-1.4.0.5-b1c3c9997492fcc63225dc59ed6cb11e
+    yesod-auth-1.4.13.2-70fbc297215ea529cd48a72c94deb537
+    yesod-core-1.4.20.2-aaffcf2ac447630f203677e559cbeb7c
+    yesod-form-1.4.7.1-5c01650ad8afe65749d51c18021fd186
+    yesod-persistent-1.4.0.5-144b1d8baf9d0000ea8d859d50d02dcc
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
